@@ -12,8 +12,8 @@ c    Spectral correlator description:	numchan,nspect,sdf,sfreq,ischan,nschan
 c
 	integer maxspect
 	parameter(maxspect=8)
-        integer maxsrc,maxpol,maxpnt,maxpolar
-        parameter(maxsrc=1000,maxpol=4,maxpnt=500,maxpolar=20)
+        integer maxsrc,maxpol,maxpnts,maxpolar
+        parameter(maxsrc=1000,maxpol=4,maxpnts=500,maxpolar=20)
 c
 	double precision sfreq(maxspect),sdf(maxspect),lo1,lo2,freqif
 	real wfreq(maxspect),wwidth(maxspect)
